Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/tests.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/tests.py	(revision 13306)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/tests.py	(revision 13329)
@@ -111,7 +111,6 @@
         self.assertMatches('...Amount Authorized...',
                            self.browser.contents)
-        self.assertMatches(
-            '...<span>39400.0</span>...',
-            self.browser.contents)
+        self.assertTrue(
+            '<span>39400.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
 
@@ -146,7 +145,6 @@
         self.browser.getLink(self.value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>31500.0</span>...',
-            self.browser.contents)
+        self.assertTrue(
+            '<span>31500.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
 
@@ -166,5 +164,5 @@
             self.browser.contents)
         self.assertTrue(
-            'item_name="School Fee" item_amt="2820000" bank_id="120" acct_num="1771586608"' in
+            'item_name="School Fee" item_amt="2820000" bank_id="10" acct_num="0106259811"' in
             self.browser.contents)
         self.assertTrue(
@@ -208,7 +206,5 @@
                            self.browser.contents)
         # Maint fee is taken from the hostel object
-        self.assertMatches(
-            '...<span>876.0</span>...',
-            self.browser.contents)
+        self.assertTrue('<span>876.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         # Manager can access InterswitchForm
@@ -222,12 +218,12 @@
         self.assertMatches('...Total Amount Authorized:...',
                            self.browser.contents)
-        self.assertMatches(
-            '...<input type="hidden" name="pay_item_id" value="102" />...',
-            self.browser.contents)
-        self.assertMatches(
-            '...<input type="hidden" name="amount" value="87600" />...',
-            self.browser.contents)
-        self.assertMatches(
-            '...item_name="Hostel Maintenance" item_amt="57600" bank_id="31" acct_num="0039050937"...',
+        self.assertTrue(
+            '<input type="hidden" name="pay_item_id" value="102" />' in
+            self.browser.contents)
+        self.assertTrue(
+            '<input type="hidden" name="amount" value="87600" />' in
+            self.browser.contents)
+        self.assertTrue(
+            'item_name="Hostel Maintenance" item_amt="57600" bank_id="10" acct_num="0106259811"' in
             self.browser.contents)
 
@@ -239,7 +235,5 @@
         value = ctrl.options[2]
         self.browser.getLink(value).click()
-        self.assertMatches(
-            '...<span>6000.0</span>...',
-            self.browser.contents)
+        self.assertTrue('<span>6000.0</span>' in self.browser.contents)
         # Manager can access InterswitchForm
         self.browser.getLink("CollegePAY", index=0).click()
@@ -248,19 +242,19 @@
         self.assertEqual(self.student['payments'][self.value].gateway_amt, 300.0)
         self.assertEqual(self.student['payments'][self.value].thirdparty_amt, 1800.0)
-        self.assertMatches('...<input type="hidden" name="pay_item_id" value="101" />...',
+        self.assertTrue('<input type="hidden" name="pay_item_id" value="101" />' in
                            self.browser.contents)
         self.assertMatches('...Total Amount Authorized:...',
                            self.browser.contents)
-        self.assertMatches(
-            '...<input type="hidden" name="amount" value="600000" />...',
-            self.browser.contents)
-        self.assertMatches(
-            '...item_name="School Fee" item_amt="270000" bank_id="120" acct_num="1771586608"...',
-            self.browser.contents)
-        self.assertMatches(
-            '...item_name="Dalash" item_amt="180000" bank_id="117" acct_num="1013196791"...',
-            self.browser.contents)
-        self.assertMatches(
-            '...item_name="BT Education" item_amt="120000" bank_id="117" acct_num="1010764827"...',
+        self.assertTrue(
+            '<input type="hidden" name="amount" value="600000" />' in
+            self.browser.contents)
+        self.assertTrue(
+            'item_name="School Fee" item_amt="270000" bank_id="10" acct_num="0106259811"' in
+            self.browser.contents)
+        self.assertTrue(
+            'item_name="Dalash" item_amt="180000" bank_id="117" acct_num="1013196791"' in
+            self.browser.contents)
+        self.assertTrue(
+            'item_name="BT Education" item_amt="120000" bank_id="117" acct_num="1010764827"' in
             self.browser.contents)
 
@@ -278,6 +272,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>6800.0</span>...', self.browser.contents)
+        self.assertTrue('<span>6800.0</span>' in self.browser.contents)
         self.browser.getLink("CollegePAY", index=0).click()
         self.assertEqual(self.student['payments'][value].amount_auth, 6800.0)
@@ -294,6 +287,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>5000.0</span>...', self.browser.contents)
+        self.assertTrue('<span>5000.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -311,6 +303,6 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>1015.0</span>...', self.browser.contents)
+        self.assertTrue(
+            '<span>1015.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -328,6 +320,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>500.0</span>...', self.browser.contents)
+        self.assertTrue('<span>500.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -345,6 +336,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>6000.0</span>...', self.browser.contents)
+        self.assertTrue('<span>6000.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -362,6 +352,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>7000.0</span>...', self.browser.contents)
+        self.assertTrue('<span>7000.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -379,6 +368,5 @@
         self.browser.getLink(value).click()
         self.assertMatches('...Amount Authorized...', self.browser.contents)
-        self.assertMatches(
-            '...<span>1900.0</span>...', self.browser.contents)
+        self.assertTrue('<span>1900.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
         self.browser.getLink("CollegePAY", index=0).click()
@@ -400,11 +388,11 @@
         self.browser.open(self.payments_path + '/xyz')
         self.browser.getLink("CollegePAY", index=0).click()
-        self.assertMatches('...<input type="hidden" name="pay_item_id" value="000" />...',
-                           self.browser.contents)
+        self.assertTrue('<input type="hidden" name="pay_item_id" value="000" />'
+                           in self.browser.contents)
         self.assertMatches('...Total Amount Authorized:...',
                            self.browser.contents)
         self.assertEqual(self.student.current_mode, 'nd_ft')
-        self.assertMatches(
-            '...<input type="hidden" name="amount" value="87600" />...',
+        self.assertTrue(
+            '<input type="hidden" name="amount" value="87600" />' in
             self.browser.contents)
         delta = timedelta(days=8)
@@ -546,7 +534,5 @@
         self.assertMatches('...Amount Authorized...',
                            self.browser.contents)
-        self.assertMatches(
-            '...<span>3333.0</span>...',
-            self.browser.contents)
+        self.assertTrue('<span>3333.0</span>' in self.browser.contents)
         self.payment_url = self.browser.url
 
@@ -563,5 +549,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="Application" '
-            'item_amt="253300" bank_id="120" acct_num="1771440667" />'
+            'item_amt="253300" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
 
@@ -575,5 +561,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="Application" '
-            'item_amt="253300" bank_id="120" acct_num="1771440667" />'
+            'item_amt="253300" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
         # Commission or bribe?
@@ -596,5 +582,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="Application" '
-            'item_amt="253300" bank_id="120" acct_num="1771440667" />'
+            'item_amt="253300" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
         # No 'commission', no provider fee in 2013
@@ -671,5 +657,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="Application" '
-            'item_amt="253300" bank_id="120" acct_num="1771440667" />'
+            'item_amt="253300" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
         delta = timedelta(days=8)
@@ -721,5 +707,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="ND Transcript (local)" '
-            'item_amt="450000" bank_id="120" acct_num="1771440667" />'
+            'item_amt="450000" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
 
@@ -734,5 +720,5 @@
         self.assertTrue(
             '<item_detail item_id="1" item_name="Log Book" '
-            'item_amt="55444" bank_id="120" acct_num="1771440667" />'
+            'item_amt="55444" bank_id="10" acct_num="0106259811" />'
             in self.browser.contents)
 

Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/browser.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/browser.py	(revision 13306)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/interswitch/browser.py	(revision 13329)
@@ -51,39 +51,39 @@
 httplib.HTTPConnection.debuglevel = 0
 
 #All special payments moved to Skye Bank on 03-09-2015
 SPECIAL_PAYMENT_PARAMS = {
-    'certificate': ('111', 200.0, 300.0, '1771440667', '120'),
-    'state_result': ('112', 200.0, 300.0, '1771440667', '120'),
-    'transcript_local': ('113', 200.0, 300.0, '1771440667', '120'),
-    'transcript_foreign': ('114', 200.0, 300.0, '1771440667', '120'),
-    'ver_result': ('115', 200.0, 300.0, '1771440667', '120'),
-    'change_course': ('116', 200.0, 300.0, '1771440667', '120'),
-    'change_inst': ('117', 200.0, 300.0, '1771440667', '120'),
-    'jamb_reject': ('118', 200.0, 300.0, '1771440667', '120'),
-    'cert_of_cert': ('119', 200.0, 300.0, '1771440667', '120'),
-    'ref_let': ('120', 200.0, 300.0, '1771440667', '120'),
-    'proc_cert': ('121', 200.0, 300.0, '1771440667', '120'),
-    'loss_idcard': ('122', 6.0, 9.0, '1771440667', '120'),
-    'loss_examcard': ('123', 3.0, 4.5, '1771440667', '120'),
-    'loss_result': ('124', 200.0, 300.0, '1771440667', '120'),
-    'loss_receipt': ('125', 200.0, 300.0, '1771440667', '120'),
-    'loss_clearance': ('126', 200.0, 300.0, '1771440667', '120'),
-    'conv_brochure': ('127', 200.0, 300.0, '1771440667', '120'),
-    'hnd_certificate': ('128', 200.0, 300.0, '1771440667', '120'),
-    'hnd_state_result': ('129', 200.0, 300.0, '1771440667', '120'),
-    'hnd_transcript_local': ('130', 200.0, 300.0, '1771440667', '120'),
-    'hnd_transcript_foreign': ('131', 200.0, 300.0, '1771440667', '120'),
-    'staff_loss_idcard': ('132', 6.0, 9.0, '1771440667', '120'),
-    'hnd_conv_brochure': ('133', 200.0, 300.0, '1771440667', '120'),
-    'pgd_state_result': ('134', 200.0, 300.0, '1771440667', '120'),
-    'pgd_conv_brochure': ('135', 200.0, 300.0, '1771440667', '120'),
-    'pgd_certificate': ('136', 200.0, 300.0, '1771440667', '120'),
-    'log_book': ('137', 3.0, 4.5, '1771440667', '120'),
-    'pgd_transcript_foreign': ('138', 200.0, 300.0, '1771440667', '120'),
-    'pgd_transcript_local': ('139', 200.0, 300.0, '1771440667', '120'),
-    'jamb_regularization': ('140', 200.0, 300.0, '1771440667', '120'),
-    'utme_registration': ('142', 6.0, 9.0, '1771440667', '120'),
-    'utme_cbt': ('143', 6.0, 9.0, '1771440667', '120'),
-    'nysc_id_card': ('144', 6.0, 9.0, '1771440667', '120'),
+    'certificate': ('111', 200.0, 300.0, '0106259811', '10'),
+    'state_result': ('112', 200.0, 300.0, '0106259811', '10'),
+    'transcript_local': ('113', 200.0, 300.0, '0106259811', '10'),
+    'transcript_foreign': ('114', 200.0, 300.0, '0106259811', '10'),
+    'ver_result': ('115', 200.0, 300.0, '0106259811', '10'),
+    'change_course': ('116', 200.0, 300.0, '0106259811', '10'),
+    'change_inst': ('117', 200.0, 300.0, '0106259811', '10'),
+    'jamb_reject': ('118', 200.0, 300.0, '0106259811', '10'),
+    'cert_of_cert': ('119', 200.0, 300.0, '0106259811', '10'),
+    'ref_let': ('120', 200.0, 300.0, '0106259811', '10'),
+    'proc_cert': ('121', 200.0, 300.0, '0106259811', '10'),
+    'loss_idcard': ('122', 6.0, 9.0, '0106259811', '10'),
+    'loss_examcard': ('123', 3.0, 4.5, '0106259811', '10'),
+    'loss_result': ('124', 200.0, 300.0, '0106259811', '10'),
+    'loss_receipt': ('125', 200.0, 300.0, '0106259811', '10'),
+    'loss_clearance': ('126', 200.0, 300.0, '0106259811', '10'),
+    'conv_brochure': ('127', 200.0, 300.0, '0106259811', '10'),
+    'hnd_certificate': ('128', 200.0, 300.0, '0106259811', '10'),
+    'hnd_state_result': ('129', 200.0, 300.0, '0106259811', '10'),
+    'hnd_transcript_local': ('130', 200.0, 300.0, '0106259811', '10'),
+    'hnd_transcript_foreign': ('131', 200.0, 300.0, '0106259811', '10'),
+    'staff_loss_idcard': ('132', 6.0, 9.0, '0106259811', '10'),
+    'hnd_conv_brochure': ('133', 200.0, 300.0, '0106259811', '10'),
+    'pgd_state_result': ('134', 200.0, 300.0, '0106259811', '10'),
+    'pgd_conv_brochure': ('135', 200.0, 300.0, '0106259811', '10'),
+    'pgd_certificate': ('136', 200.0, 300.0, '0106259811', '10'),
+    'log_book': ('137', 3.0, 4.5, '0106259811', '10'),
+    'pgd_transcript_foreign': ('138', 200.0, 300.0, '0106259811', '10'),
+    'pgd_transcript_local': ('139', 200.0, 300.0, '0106259811', '10'),
+    'jamb_regularization': ('140', 200.0, 300.0, '0106259811', '10'),
+    'utme_registration': ('142', 6.0, 9.0, '0106259811', '10'),
+    'utme_cbt': ('143', 6.0, 9.0, '0106259811', '10'),
+    'nysc_id_card': ('144', 6.0, 9.0, '0106259811', '10'),
     }
 
@@ -121,37 +121,37 @@
         gateway_amt = GATEWAY_AMT
         self.pay_item_id = '000'
-        xmldict['institution_acct'] = "1751084083"
-        xmldict['institution_bank_id'] = "120"
+        xmldict['institution_acct'] = "0106259811"
+        xmldict['institution_bank_id'] = "10"
         if self.context.p_category == 'schoolfee':
             self.pay_item_id = '101'
             dalash_amt = 1800.0
             provider_amt = 1200.0
-            if not student.current_mode.endswith('_pt'):
+            if not student.current_mode.endswith('_we'):
                 if xmldict['faculty'] in ('CPGS',):
-                    xmldict['institution_acct'] = "1771586608"    #changed account no. from 1771180233
-                    xmldict['institution_bank_id'] = '120'
+                    xmldict['institution_acct'] = "0106259811"   
+                    xmldict['institution_bank_id'] = '10'
                 elif xmldict['faculty'] in ('IAS',):
-                    xmldict['institution_acct'] = "1771586608"  #Changed from FBN to SKYE Bank
-                    xmldict['institution_bank_id'] = '120'
+                    xmldict['institution_acct'] = "0106259811"  
+                    xmldict['institution_bank_id'] = '10'
                     self.pay_item_id = '107'
                 elif xmldict['faculty'] in ('IES',):
-                    xmldict['institution_acct'] = "0693033406" #Changed from FBN to Access Bank
-                    xmldict['institution_bank_id'] = '31'
+                    xmldict['institution_acct'] = "0106259811" 
+                    xmldict['institution_bank_id'] = '10'
                     self.pay_item_id = '109'
                 elif xmldict['faculty'] in ('IFMS',):
-                    xmldict['institution_acct'] = "2013910271" #changed bank from GTBank to FBN
-                    xmldict['institution_bank_id'] = '8'
+                    xmldict['institution_acct'] = "0106259811" 
+                    xmldict['institution_bank_id'] = '10'
                     self.pay_item_id = '106'
                 elif xmldict['faculty'] in ('IOT',):
-                    xmldict['institution_acct'] = "0106259811"    #changed from SKYE Bank to GTbank
+                    xmldict['institution_acct'] = "0106259811"    
                     xmldict['institution_bank_id'] = '10'
                     self.pay_item_id = '110'
                 elif xmldict['faculty'] in ('IICT',):
-                    xmldict['institution_acct'] = "1100019929" #changed from FBN to Keystone Bank
-                    xmldict['institution_bank_id'] = '123'
+                    xmldict['institution_acct'] = "0106259811" 
+                    xmldict['institution_bank_id'] = '10'
                     self.pay_item_id = '108'
             else:
-                xmldict['institution_acct'] = "0838798020"  #part-time fees acquired by FCMB
-                xmldict['institution_bank_id'] = '76'
+                xmldict['institution_acct'] = "0106259811"  
+                xmldict['institution_bank_id'] = '10'
                 #Introduce a pay_item_id for part-time for the first time on this portal
                 self.pay_item_id = '145'
@@ -166,6 +166,6 @@
         elif 'maintenance' in self.context.p_category:
             self.pay_item_id = '102'
-            xmldict['institution_acct'] = "0039050937"
-            xmldict['institution_bank_id'] = '31'
+            xmldict['institution_acct'] = "0106259811"
+            xmldict['institution_bank_id'] = '10'
             dalash_amt = 0.0
             provider_amt = 0.0
@@ -239,35 +239,23 @@
         xmldict['institution_bank_id'] = '00'
         if self.applicant.applicant_id.startswith('hnd'):
-            xmldict['institution_acct'] = '1771440667'
-            xmldict['institution_bank_id'] = '120'
+            xmldict['institution_acct'] = '0106259811'
+            xmldict['institution_bank_id'] = '10'
         elif self.applicant.applicant_id.startswith('nd'):
-            xmldict['institution_acct'] = '1771440667'
-            xmldict['institution_bank_id'] = '120'
+            xmldict['institution_acct'] = '0106259811'
+            xmldict['institution_bank_id'] = '10'
         elif self.applicant.applicant_id.startswith('rmd'):
-            xmldict['institution_acct'] = '1771440667'
-            xmldict['institution_bank_id'] = '120'
+            xmldict['institution_acct'] = '0106259811'
+            xmldict['institution_bank_id'] = '10'
         elif self.applicant.applicant_id.startswith('pgft'):
-            xmldict['institution_acct'] = '1751084083'
-            xmldict['institution_bank_id'] = '120'
+            xmldict['institution_acct'] = '0106259811'
+            xmldict['institution_bank_id'] = '10'
         elif self.applicant.applicant_id.startswith('prejambites') or \
             self.applicant.applicant_id.startswith('putme'):
-            # reverting for prejambites to GTBank '0106259811' from FBN '2013910271'
             xmldict['institution_acct'] = '0106259811'
             xmldict['institution_bank_id'] = '10'
             self.pay_item_id = '104'
-            # Until 14/9/2014 we have not sent split amount data for pre applications.
-            # To compenstate the loss we temporarily doubled the split amounts
-            # until 20/9/2014, see ticket 75.
-            #provider_amt = 600.0
-            #dalash_amt = 400.0
         elif self.applicant.applicant_id.startswith('pre'):
-            # changed for pre-applicants from GTBank '0106259811' to Skye Bank '1771440667'
-            xmldict['institution_acct'] = '1771440667'
-            xmldict['institution_bank_id'] = '120'
-            # Until 14/9/2014 we have not sent split amount data for pre applications.
-            # To compenstate the loss we temporarily doubled the split amounts
-            # until 20/9/2014, see ticket 75.
-            #provider_amt = 600.0
-            #dalash_amt = 400.0
+            xmldict['institution_acct'] = '0106259811'
+            xmldict['institution_bank_id'] = '10'
         elif self.applicant.applicant_id.startswith('special'):
             if self.context.p_category in SPECIAL_PAYMENT_PARAMS.keys():
@@ -51,39 +51,39 @@
 httplib.HTTPConnection.debuglevel = 0
 
-#All special payments moved to Skye Bank on 03-09-2015
+#All special payments moved to GTBank on 15-10-2015
 SPECIAL_PAYMENT_PARAMS = {